@@ -4,35 +4,19 @@ use 5.008001;
 use strict;
 use warnings;
 
-use Exporter::Tiny;
 use List::MoreUtils qw(any);
 use Scalar::Util qw(blessed);
 use Sub::Infix qw(infix);
 
 BEGIN {
 	$match::simple::AUTHORITY = 'cpan:TOBYINK';
-	$match::simple::VERSION   = '0.007_03';
+	$match::simple::VERSION   = '0.001';
 }
 
-our @ISA       = qw( Exporter::Tiny );
+use base "Exporter::TypeTiny";
 our @EXPORT    = qw( M );
 our @EXPORT_OK = qw( match );
 
-unless (($ENV{MATCH_SIMPLE_IMPLEMENTATION}||'') =~ /pp/i)
-{
-	eval { require match::simple::XS };
-}
-
-eval( match::simple::XS->can('match') ? <<'XS' : <<'PP' );
-
-sub IMPLEMENTATION () { "XS" }
-
-*match = *match::simple::XS::match;
-
-XS
-
-sub IMPLEMENTATION () { "PP" }
-
 sub match
 {
 	no warnings qw(uninitialized numeric);
@@ -45,15 +29,13 @@ sub match
 	return do{ local $_ = $a; !!$b->($a) } if ref($b) eq q(CODE);
 	return any { match($a, $_) } @$b       if ref($b) eq q(ARRAY);
 	return !!$b->check($a)                 if blessed($b) && $b->isa("Type::Tiny");
-	return !!$b->MATCH($a, 1)              if blessed($b) && $b->can("MATCH");
-	return eval 'no warnings; !!($a~~$b)'  if blessed($b) && $] >= 5.010 && do { require overload; overload::Method($b, "~~") };
+	return !!$b->MATCH($a)                 if blessed($b) && $b->can("MATCH");
+	return eval 'no warnings; !!($a~~$b)'  if blessed($b) && $] >= 5.010 && do { require overload; overload::Overloaded($b) };
 	
 	require Carp;
 	Carp::croak("match::simple cannot match anything against: $b");
 }
 
-PP
-
 *M = &infix(\&match);
 
 __END__
@@ -130,7 +112,7 @@ If any other value appears on the right hand side, the operator will croak.
 
 =back
 
-If you don't like the crazy L<Sub::Infix> operator, you can alternatively
+If you don't like the crazy C<Sub::Infix> operator, you can alternatively
 export a more normal function:
 
    use v5.10;
@@ -141,38 +123,12 @@ export a more normal function:
       say "$this matches $that";
    }
 
-If you're making heavy use of this module, then this is probably your best
-option, as it runs significantly faster.
-
-=head2 XS Backend
-
-If you install match::simple::XS, a faster XS-based implementation will be
-used instead of the pure Perl functions. Depending on what sort of match you
-are doing, this is likely to be several times faster. In extreme cases, such
-as matching a string in an arrayref, it can be twenty-five times faster, or
-more. However, where C<< $that >> is a single regexp, it's around 30% slower.
-Overall though, I think the performance improvement is worthwhile.
-
-If you want to take advantage of this speed up, use the C<match> function
-rather than the C<< |M| >> operator. Otherwise all your gains will be lost to
-the slow implementation of operator overloading.
-
-The constant C<< match::simple::IMPLEMENTATION >> tells you which backend
-is currently in use.
-
-=head2 Environment
-
-Setting the C<MATCH_SIMPLE_IMPLEMENTATION> environment variable to "PP"
-encourages match::simple to use the pure Perl backend.
-
 =begin trustme
 
 =item M
 
 =item match
 
-=item IMPLEMENTATION
-
 =end trustme
 
 =head1 BUGS
@@ -184,7 +140,7 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=match-simple>.
 
 L<match::smart>.
 
-This module uses L<Exporter::Tiny>.
+This module uses L<Exporter::TypeTiny>.
 
 =head1 AUTHOR
 
@@ -192,7 +148,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014 by Toby Inkster.
+This software is copyright (c) 2013 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
